#[repr(u64)]pub enum Units {
Seconds = 1,
Minutes = 60,
Hours = 3_600,
Days = 86_400,
Weeks = 604_800,
Months = 2_678_400,
Years = 31_536_000,
}Expand description
Possible units for a component of a relative time.
Intended to be used with Reltime::format and Reltime::format_with_timetable to control
units are selected to decompose a Reltime value for formatting. See those method for
details.
Variants
Seconds = 1
Minutes = 60
Hours = 3_600
Days = 86_400
Weeks = 604_800
Months = 2_678_400
Years = 31_536_000