FormattedReltime

Struct FormattedReltime 

pub struct FormattedReltime(/* private fields */);
A formatted time duration

This type represents a time duration which has been decomposed into the sum of 2 components of distinct units. The only intended purpose of this type is to be rendered via Display. Values of this type are created by Reltime::format.

This type is similar to Reltime but differs from it in that the specific decomposition of the duration into unit components is already determined in values of this type, but values of Reltime have not yet been decomposed.