ThreshSpec

Type Alias ThreshSpec 

pub type ThreshSpec = (u64, Units, Units);
A type for constructing threshold tables for Reltime::format_with_timetable. A value of this type, x means that a duration less than x.0 seconds will be docomposed into components with major units x.1 and minor units x.2, unless another ThreshSpec value with a lower .0 component is also greater than the duration.